# Django Charm

Welcome to **Django Charm**! This is a handy package that can save your time so you can focus on building what truly matters in your Django project.

## Features

- No need to manually create and configure a Django project and app separately.
- Automatically handles the `urls.py` and `settings.py` setup.
- Instantly creates `index.html` with a starter template — ready to go.

---

## django-charm

This package allows you to create a Django project and app by executing a single command (including generating `views.py`, `urls.py`, and a basic `index.html` template).

## Table of Contents
- [Installation](#installation)
- [Features](#features)
- [Examples](#examples)
- [License](#license)


## Installation

```bash
pip install django-charm
```





# Examples:

  ######   Method 1
  Open Terminal  provide the package name and press enter.
 You will then be prompted to enter the project name and app name.
 Once you provide them, your app will be ready within seconds!


```bash

django-charm

```
  ######  Method 2
   Provide the  package name and  pass the project name and app name as an argument as shown below:
```bash

django-charm  -p myproject -a myapp

```
## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/AlokDas1234/djangocharm/blob/main/LICENSE) file for details.

